@@ -1,12 +1,13 @@
+__all__ = [
+    'Sample',
+    'Batch',
+    'Dataset',
+    'StreamDataset',
+    'Vocab',
+]
+__version__ = '0.0.3'
+
 from .batches import Batch
 from .datasets import Dataset, StreamDataset
 from .samples import Sample
 from .vocab import Vocab
-
-__all__ = [
-    Sample,
-    Batch,
-    Dataset,
-    StreamDataset,
-    Vocab,
-]
